==> haskell-parser-combinators-1.2.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 1.2.0
id: parser-combinators-1.2.0-2keeVZyMyoBVuECNB2kOs
key: parser-combinators-1.2.0-2keeVZyMyoBVuECNB2kOs
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
        Alex Washburn <github@recursion.ninja>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
abi: d185ec5235dfda00042b78202ca79628
exposed: True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
import-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.2.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parser-combinators-1.2.0
hs-libraries: HSparser-combinators-1.2.0-2keeVZyMyoBVuECNB2kOs
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-parser-combinators-1.2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-parser-combinators.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: parser-combinators
version: 1.2.1
id: parser-combinators-1.2.1-1g1MOzTzLdh8NjDlkAmMlz
key: parser-combinators-1.2.1-1g1MOzTzLdh8NjDlkAmMlz
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
        Alex Washburn <github@recursion.ninja>
homepage: https://github.com/mrkkrp/parser-combinators
synopsis: Lightweight package providing commonly useful parser combinators
description:
    Lightweight package providing commonly useful parser combinators.
category: Parsing
abi: 4234b9efdddf59da5521a97f8fb12823
exposed: True
exposed-modules:
    Control.Applicative.Combinators
    Control.Applicative.Combinators.NonEmpty
    Control.Applicative.Permutations Control.Monad.Combinators
    Control.Monad.Combinators.Expr Control.Monad.Combinators.NonEmpty
import-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.2.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/parser-combinators-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/parser-combinators-1.2.1
hs-libraries: HSparser-combinators-1.2.1-1g1MOzTzLdh8NjDlkAmMlz
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-parser-combinators/html/parser-combinators.haddock
haddock-html: /usr/share/doc/haskell-parser-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
